---
feature_story: FS_27_16_67_19
feature_title: line syntax
feature_status: TBD
---

This doc is an umbrella one about command line syntax.

# Syntax

In short, current syntax is simplistic = keywords separated by white spaces.

# Interpretation

Interpretation logic depends on "schema" (what command and its args expect) together with existing indexed data.

# Implementation

At the moment, the parsing logic is implemented in two classes:
*   `ParsedContext.py` for tokenization
*   `InterpContext.py` for arg consumption with respect to FS_97_64_39_94 arg buckets

# Potential additions

In the future, the plan is to add two extra syntax elements:
*   FS_20_88_05_60: named args

# See also

Feature stories related to syntax more than others:
*   FS_06_99_43_60: list arg value
*   FS_15_79_76_85: line processor
*   FS_18_64_57_18: function with indefinite input data envelopes like varargs
*   FS_20_88_05_60: named args
*   FS_23_62_89_43: tangent arg value completion
*   FS_32_05_46_00: `startwith` vs `contains`
*   FS_44_36_84_88: consume args one by one
*   FS_51_67_38_37: impossible arg combinations
*   FS_61_67_08_53: non-searchable arg types
*   FS_76_29_13_28: arg consumption priorities
*   FS_92_75_93_01: clean command line
*   FS_97_64_39_94: arg buckets
*   FS_99_81_19_25: no space in options
